plugin

package
v0.0.0-...-84a4305 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 24, 2024 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const NAME_INDEX = 2
const PREFIX = "vision-plugin"

plugin executable follows the format: vision-plugin-[name]-[version]

[0]    [1]    [2]    [3]
const VERSION_INDEX = 3

Variables

This section is empty.

Functions

This section is empty.

Types

type Executor

type Executor struct {
	FullPath string
}

func NewExecutor

func NewExecutor(path string) Executor

func (Executor) Generate

func (e Executor) Generate() (*api.Generate, error)

func (Executor) Info

func (e Executor) Info() (*api.Info, error)

info returns usage and descriptions of the plugin TODO(steve): make info resp part of the plugin API

func (Executor) Init

func (e Executor) Init() (*api.Init, error)

func (Executor) Version

func (e Executor) Version() (*api.Version, error)

type Plugin

type Plugin struct {
	Name     string
	Version  string
	FullPath string
}

func Find

func Find() ([]Plugin, error)

Find searches all dirs in the PATH envar to find binaries with specific vision formatting and assigns them to a map. The formatting is `vision-plugin-[plugin-name]-[version-number]`

Jump to